==> downloads.html?file=gigkalender_v1.2.61_059.zip: gigkalender/admin/includes/setup/javascript.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
echo '<script type="text/javascript">
        <!--
          function allCalenderFormAttributes()
          {
            document.getElementById("Setup").SetupCalendarAttributeInAddGigFormTranslated.value = "'.translateLanguageVarString($allBackendCalenderFormAttributes).'";
            document.getElementById("Setup").SetupCalendarAttributeInAddGigForm.value = "'.$allBackendCalenderFormAttributes.'";
          }
          function standardFrontendAttributes()
          {
            document.getElementById("Setup").SetupFrontendAttributesTranslated.value = "'.translateLanguageVarString($StandardFrontendAttributes).'";
            document.getElementById("Setup").SetupFrontendAttributes.value = "'.$StandardFrontendAttributes.'";
          }
          function allFrontendAttributes()
          {
            document.getElementById("Setup").SetupFrontendAttributesTranslated.value = "'.translateLanguageVarString($allFrontendAttributes).'";
            document.getElementById("Setup").SetupFrontendAttributes.value = "'.$allFrontendAttributes.'";
          }
          function standardFrontendDetailAttributes()
          {
            document.getElementById("Setup").SetupFrontendDetailAttributesTranslated.value = "'.translateLanguageVarString($StandardFrontendDetailAttributes).'";
            document.getElementById("Setup").SetupFrontendDetailAttributes.value = "'.$StandardFrontendDetailAttributes.'";
          }
          function allFrontendDetailAttributes()
          {
            document.getElementById("Setup").SetupFrontendDetailAttributesTranslated.value = "'.translateLanguageVarString($allFrontendAttributes).'";
            document.getElementById("Setup").SetupFrontendDetailAttributes.value = "'.$allFrontendAttributes.'";
          }
        //-->
      </script>';
?>

==> downloads.html?file=gigkalender_v1.2.75_017.zip: gigkalender/admin/includes/setup/javascript.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
echo '<script type="text/javascript">
        <!--
          function allCalenderFormAttributes()
          {
            document.getElementById("Setup").SetupCalendarAttributeInAddGigFormTranslated.value = "'.translateLanguageVarString($allBackendCalenderFormAttributes).'";
            document.getElementById("Setup").SetupCalendarAttributeInAddGigForm.value = "'.$allBackendCalenderFormAttributes.'";
          }
          function standardFrontendAttributes()
          {
            document.getElementById("Setup").SetupFrontendAttributesTranslated.value = "'.translateLanguageVarString($StandardFrontendAttributes).'";
            document.getElementById("Setup").SetupFrontendAttributes.value = "'.$StandardFrontendAttributes.'";
          }
          function allFrontendAttributes()
          {
            document.getElementById("Setup").SetupFrontendAttributesTranslated.value = "'.translateLanguageVarString($allFrontendAttributes).'";
            document.getElementById("Setup").SetupFrontendAttributes.value = "'.$allFrontendAttributes.'";
          }
          function standardFrontendDetailAttributes()
          {
            document.getElementById("Setup").SetupFrontendDetailAttributesTranslated.value = "'.translateLanguageVarString($StandardFrontendDetailAttributes).'";
            document.getElementById("Setup").SetupFrontendDetailAttributes.value = "'.$StandardFrontendDetailAttributes.'";
          }
          function allFrontendDetailAttributes()
          {
            document.getElementById("Setup").SetupFrontendDetailAttributesTranslated.value = "'.translateLanguageVarString($allFrontendDetailAttributes).'";
            document.getElementById("Setup").SetupFrontendDetailAttributes.value = "'.$allFrontendDetailAttributes.'";
          }
        //-->
      </script>';
?>
